==> haskell-http-client-0.7.19-52.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client
version:              0.7.19
visibility:           public
id:                   http-client-0.7.19-76DosIrYZ8GJOiYGyhGmc9
key:                  http-client-0.7.19-76DosIrYZ8GJOiYGyhGmc9
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:             An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.

category:             Network
abi:                  1b76625b21b7261765c956190b3d4c2c
exposed:              True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.Internal
    Network.HTTP.Client.MultipartFormData

hidden-modules:
    Network.HTTP.Client.Body Network.HTTP.Client.Connection
    Network.HTTP.Client.Cookies Network.HTTP.Client.Core
    Network.HTTP.Client.Headers Network.HTTP.Client.Manager
    Network.HTTP.Client.Request Network.HTTP.Client.Response
    Network.HTTP.Client.Types Network.HTTP.Client.Util
    Network.HTTP.Proxy Network.PublicSuffixList.Lookup
    Network.PublicSuffixList.Types Network.PublicSuffixList.Serialize
    Network.PublicSuffixList.DataStructure Data.KeyedPool

import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-client-0.7.19
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-client-0.7.19
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-client-0.7.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-client
hs-libraries:         HShttp-client-0.7.19-76DosIrYZ8GJOiYGyhGmc9
depends:
    array-0.5.6.0 async-2.2.5-1Z88VuXAsSjFYCStMD3XFv base-4.18.2.1
    base64-bytestring-1.2.1.0-DIdtXjiFLF0sICzGCxvgr
    blaze-builder-0.4.4.1-KJNFYglh6UuC57b0V7Eyim bytestring-0.11.5.3
    case-insensitive-1.2.1.0-3fPl2hvou1nDiCO1iE2i5z containers-0.6.7
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 deepseq-1.4.8.1
    exceptions-0.10.7 filepath-1.4.300.1 ghc-prim-0.10.0
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS
    iproute-1.7.15-8MQv32arzXu8ybbx4AUApr
    mime-types-0.1.2.0-2lnuHjhOzQ4DFNhuFJ9ART
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe
    network-uri-2.6.4.2-69jfmnohyG88ZQKNy7a5sS
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm stm-2.5.1.0
    streaming-commons-0.2.3.0-E1A8MXIidsEIETQNDtfU1f text-2.0.2
    time-1.12.2 transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html:         /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-0.7.19-53-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client
version:              0.7.19
visibility:           public
id:                   http-client-0.7.19-ITPZXASBEGHLmOi4NfdGY8
key:                  http-client-0.7.19-ITPZXASBEGHLmOi4NfdGY8
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:             An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.

category:             Network
abi:                  77f42901457584a02f3ef7b23693a75c
exposed:              True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.Internal
    Network.HTTP.Client.MultipartFormData

hidden-modules:
    Network.HTTP.Client.Body Network.HTTP.Client.Connection
    Network.HTTP.Client.Cookies Network.HTTP.Client.Core
    Network.HTTP.Client.Headers Network.HTTP.Client.Manager
    Network.HTTP.Client.Request Network.HTTP.Client.Response
    Network.HTTP.Client.Types Network.HTTP.Client.Util
    Network.HTTP.Proxy Network.PublicSuffixList.Lookup
    Network.PublicSuffixList.Types Network.PublicSuffixList.Serialize
    Network.PublicSuffixList.DataStructure Data.KeyedPool

import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-client-0.7.19
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-client-0.7.19
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-client-0.7.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-client
hs-libraries:         HShttp-client-0.7.19-ITPZXASBEGHLmOi4NfdGY8
depends:
    array-0.5.6.0 async-2.2.5-1Z88VuXAsSjFYCStMD3XFv base-4.18.2.1
    base64-bytestring-1.2.1.0-DIdtXjiFLF0sICzGCxvgr
    blaze-builder-0.4.4.1-KJNFYglh6UuC57b0V7Eyim bytestring-0.11.5.3
    case-insensitive-1.2.1.0-3fPl2hvou1nDiCO1iE2i5z containers-0.6.7
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 deepseq-1.4.8.1
    exceptions-0.10.7 filepath-1.4.300.1 ghc-prim-0.10.0
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS
    iproute-1.7.15-8MQv32arzXu8ybbx4AUApr
    mime-types-0.1.2.0-2lnuHjhOzQ4DFNhuFJ9ART
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe
    network-uri-2.6.4.2-69jfmnohyG88ZQKNy7a5sS
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm stm-2.5.1.0
    streaming-commons-0.2.3.1-JQd7Uft3nuo1D7ll7sM2yO text-2.0.2
    time-1.12.2 transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html:         /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
